
from flask_wtf import FlaskForm
from wtforms import SubmitField, StringField, BooleanField, SelectField,  PasswordField
from wtforms.validators import DataRequired
from wtforms.validators import Length, Email, EqualTo
from app.models import ROLES


class EditUserForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.role.choices = [r[0] for r in ROLES]

    username = StringField('Username', validators=[Length(min=3, max=32)])
    email = StringField('Email', validators=[Length(min=6, max=40), Email()])
    first_name = StringField('First name', validators=[Length(min=1, max=32)])
    last_name = StringField('Last name', validators=[Length(min=1, max=32)])
    active = BooleanField("User is active?")
    role = SelectField("User role")

    submit = SubmitField('Submit')


class NewUserForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.role.default = "driver"
        self.role.choices = [r[0] for r in ROLES]

    username = StringField('Username', validators=[Length(min=3, max=32)])
    email = StringField('Email', validators=[Length(min=6, max=40), Email()])
    password = PasswordField('Password', validators=[DataRequired()])
    password2 = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    first_name = StringField('First name', validators=[Length(min=1, max=32)])
    last_name = StringField('Last name', validators=[Length(min=1, max=32)])
    role = SelectField("User role")

    submit = SubmitField('Submit')

class AdminResetPasswordForm(FlaskForm):
    password = PasswordField('Password', validators=[DataRequired()])
    password2 = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    submit = SubmitField('Reset password')


class EmptyForm(FlaskForm):
    submit = SubmitField('Submit')

